@@ -132,8 +132,16 @@ class CortxJupyter(ContentsManager):
             return (yield _delete__notebook_checkpoint(self._config(), checkpoint_id, path))
 
     def _config(self):
-        # cred_file = open(".credentials","w")
-        configuration  = Config(
+        creds = {'region_name':self.region_name,'bucket_name':self.bucket_name,
+        "host_name":self.host_name,"cortx_authenticator":yield self.authentication.get_credentials(),
+        "prefix": self.prefix,"endpoint_url":self.endpoint_url
+        }
+        
+        print(creds)
+        with open(".credentials", "w") as fp:
+            json.dump(creds , fp)
+
+        return Config(
             region=self.region_name,
             bucket_name=self.bucket_name,
             host_name=self.host_name,
@@ -142,9 +150,4 @@ class CortxJupyter(ContentsManager):
             multipart_uploads=self.multipart_uploads,
             endpoint_url=self.endpoint_url
         )
-        print(configuration._asdict())
-        with open(".credentials", "w") as fp:
-            json.dump(configuration._asdict() , fp)
-        # cred_file.write(json.dumps(configuration._asdict()))
-        return configuration
 
